@@ -25,7 +25,7 @@
 // Author     : Jean-Charles Lefebvre
 // Created On : 2010-03-29 14:03:23
 //
-// $Id: GPSRFile.cpp 219 2010-11-01 07:57:31Z jc.lefebvre $
+// $Id: GPSRFile.cpp 227 2010-12-08 14:06:11Z jc.lefebvre $
 //
 //***************************************************************************
 
@@ -82,6 +82,8 @@ TRANSPORTNAMES[] =
   { GPSRFile::MEANSTRANSPORT_TRUCK,        QT_TR_NOOP("Truck") },
   { GPSRFile::MEANSTRANSPORT_TAXI,         QT_TR_NOOP("Taxi") },
   { GPSRFile::MEANSTRANSPORT_BUS,          QT_TR_NOOP("Bus") },
+  { GPSRFile::MEANSTRANSPORT_SUBWAY,       QT_TR_NOOP("Subway") },
+  { GPSRFile::MEANSTRANSPORT_TRAMWAY,      QT_TR_NOOP("Tramway") },
   { GPSRFile::MEANSTRANSPORT_TUKTUK,       QT_TR_NOOP("Tuk Tuk") },
   { GPSRFile::MEANSTRANSPORT_TRAIN,        QT_TR_NOOP("Train") },
 
@@ -110,6 +112,8 @@ TRANSPORTNAMES[] =
   { GPSRFile::MEANSTRANSPORT_FREEFALL,     QT_TR_NOOP("Free Fall") },
   { GPSRFile::MEANSTRANSPORT_PARAGLIDER,   QT_TR_NOOP("Paraglider") },
   { GPSRFile::MEANSTRANSPORT_DELTAPLANE,   QT_TR_NOOP("Deltaplane") },
+  { GPSRFile::MEANSTRANSPORT_BALLOON,      QT_TR_NOOP("Balloon") },
+  { GPSRFile::MEANSTRANSPORT_ZEPPELIN,     QT_TR_NOOP("Zeppelin") },
 
   { GPSRFile::MEANSTRANSPORT_OTHER,        QT_TR_NOOP("Other") },
   { GPSRFile::MEANSTRANSPORT_FLYINGSAUCER, QT_TR_NOOP("Flying Saucer") },
@@ -538,7 +542,7 @@ void GPSRFile::writeNewTrack (time_t uiTime, const char* pszName)
 
   // data format :
   // 0 : time zone offset
-  // 1-var : asciiz, optional label
+  // 4-var : asciiz, optional label
   {
     quint8* pui = (quint8*)&pChunk->aData[0];
 
