@@ -25,7 +25,7 @@
 // Author     : Jean-Charles Lefebvre
 // Created On : 2010-03-29 14:03:17
 //
-// $Id: GPSRFile.h 219 2010-11-01 07:57:31Z jc.lefebvre $
+// $Id: GPSRFile.h 227 2010-12-08 14:06:11Z jc.lefebvre $
 //
 //***************************************************************************
 
@@ -95,6 +95,8 @@ public :
     MEANSTRANSPORT_TRUCK        = 70,
     MEANSTRANSPORT_TAXI         = 75,
     MEANSTRANSPORT_BUS          = 80,
+    MEANSTRANSPORT_SUBWAY       = 81,
+    MEANSTRANSPORT_TRAMWAY      = 82,
     MEANSTRANSPORT_TUKTUK       = 85,
     MEANSTRANSPORT_TRAIN        = 90,
     //
@@ -123,6 +125,8 @@ public :
     MEANSTRANSPORT_FREEFALL     = 220,
     MEANSTRANSPORT_PARAGLIDER   = 222,
     MEANSTRANSPORT_DELTAPLANE   = 224,
+    MEANSTRANSPORT_BALLOON      = 230,
+    MEANSTRANSPORT_ZEPPELIN     = 231,
     //
     MEANSTRANSPORT_OTHER        = 250,
     MEANSTRANSPORT_FLYINGSAUCER = 251, // easter eggs are cool :)
