@@ -25,7 +25,7 @@
 // Author     : Jean-Charles Lefebvre
 // Created On : 2010-04-22 07:39:24
 //
-// $Id: WndConfig.cpp 213 2010-10-31 10:17:24Z jc.lefebvre $
+// $Id: WndConfig.cpp 225 2010-11-22 12:07:14Z jc.lefebvre $
 //
 //***************************************************************************
 
@@ -129,7 +129,7 @@ void WndConfig::setupControls (void)
     m_pChkGpsAlwaysConnected = new QCheckBox(tr("GPS always connected"));
     m_pChkGpsAlwaysConnected->setCheckState(settings.getGpsAlwaysConnected() ? Qt::Checked : Qt::Unchecked);
 
-    m_pChkAlwaysCreateNewFile = new QCheckBox(tr("Always create new file"));
+    m_pChkAlwaysCreateNewFile = new QCheckBox(tr("Always create new file (old behavior)"));
     m_pChkAlwaysCreateNewFile->setCheckState(settings.getAlwaysCreateNewFile() ? Qt::Checked : Qt::Unchecked);
 
     m_pChkAskPointName = new QCheckBox(tr("Ask for point name before snap"));
